@@ -1,7 +1,7 @@
 //! [GET /_matrix/client/r0/account/3pid](https://matrix.org/docs/spec/client_server/r0.6.0#get-matrix-client-r0-account-3pid)
 
 use ruma_api::ruma_api;
-pub use ruma_common::thirdparty::{ThirdPartyIdentifier, ThirdPartyIdentifierInit};
+use ruma_common::thirdparty::ThirdPartyIdentifier;
 
 ruma_api! {
     metadata: {
@@ -17,9 +17,9 @@ ruma_api! {
     request: {}
 
     response: {
-        /// A list of third party identifiers the homeserver has associated with the user's
-        /// account.
-        #[serde(default, skip_serializing_if = "Vec::is_empty")]
+        /// A list of third party identifiers the homeserver has associated with the user's account.
+        #[serde(default)]
+        #[cfg_attr(feature = "compat", serde(skip_serializing_if = "Vec::is_empty"))]
         pub threepids: Vec<ThirdPartyIdentifier>,
     }
 
@@ -29,7 +29,7 @@ ruma_api! {
 impl Request {
     /// Creates an empty `Request`.
     pub fn new() -> Self {
-        Self
+        Self {}
     }
 }
 
